"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = LinearShadowCanvas;
var _reactNativeSkia = require("@shopify/react-native-skia");
var _utils = require("../utils.js");
var _react = require("react");
var _jsxRuntime = require("react/jsx-runtime");
/**
 * LinearShadowCanvas
 * -------------------
 * A Skia-based component that renders a RoundedRect with a
 * linear gradient fill. It also applies an inner shadow
 * and (optionally) a reflected light effect.
 */function LinearShadowCanvas({
  width,
  height,
  style,
  shadowColor,
  shadowOffset,
  shadowBlur,
  inset,
  reflectedLightColor,
  reflectedLightOffset,
  reflectedLightBlur,
  from = 'top',
  to = 'bottom',
  colors = ['#FFFFFF', '#FFFFFF'],
  ...props
}) {
  const isReflectedLightEnabled = props.isReflectedLightEnabled !== undefined ? props.isReflectedLightEnabled : inset;
  const boxRadius = Number(style ? style.borderRadius : 0) || 0;
  const {
    start,
    end
  } = (0, _utils.getLinearDirection)({
    width,
    height,
    from,
    to
  });
  const styles = (0, _utils.createStyles)({
    width,
    height
  });
  const outerShadowOffset = (0, _react.useMemo)(() => (0, _utils.createOuterShadowOffset)({
    inset,
    shadowColor,
    shadowBlur,
    shadowOffset
  }), [inset, shadowColor, shadowBlur, shadowOffset]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
    style: [outerShadowOffset, style, styles.canvas],
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSkia.RoundedRect, {
      x: 0,
      y: 0,
      width: width,
      height: height,
      r: boxRadius,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.LinearGradient, {
        start: start,
        end: end,
        colors: colors
      }), inset && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
        dx: shadowOffset.width,
        dy: shadowOffset.height,
        blur: shadowBlur,
        color: shadowColor,
        inner: true
      }), isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
        dx: reflectedLightOffset.width,
        dy: reflectedLightOffset.height,
        blur: reflectedLightBlur,
        color: reflectedLightColor,
        inner: true
      })]
    })
  });
}
//# sourceMappingURL=LinearShadowCanvas.js.map